==> com.liferay.layout.admin.web-4.0.54.jar: META-INF/resources/js/SelectCollectionManagementToolbarDefaultEventHandler.es.js <==
Liferay.Loader.define("layout-admin-web@4.0.54/js/SelectCollectionManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = void 0;

    var _frontendJsWeb = require("frontend-js-web");

    var _metalState = require("frontend-js-metal-web$metal-state");

    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }

    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
    }

    function _possibleConstructorReturn(self, call) {
      if (call && (_typeof(call) === "object" || typeof call === "function")) {
        return call;
      }return _assertThisInitialized(self);
    }

    function _assertThisInitialized(self) {
      if (self === void 0) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
      }return self;
    }

    function _getPrototypeOf(o) {
      _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
        return o.__proto__ || Object.getPrototypeOf(o);
      };return _getPrototypeOf(o);
    }

    function _inherits(subClass, superClass) {
      if (typeof superClass !== "function" && superClass !== null) {
        throw new TypeError("Super expression must either be null or a function");
      }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
    }

    function _setPrototypeOf(o, p) {
      _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
        o.__proto__ = p;return o;
      };return _setPrototypeOf(o, p);
    }

    var SelectCollectionManagementToolbarDefaultEventHandler = /*#__PURE__*/function (_DefaultEventHandler) {
      _inherits(SelectCollectionManagementToolbarDefaultEventHandler, _DefaultEventHandler);

      function SelectCollectionManagementToolbarDefaultEventHandler() {
        _classCallCheck(this, SelectCollectionManagementToolbarDefaultEventHandler);

        return _possibleConstructorReturn(this, _getPrototypeOf(SelectCollectionManagementToolbarDefaultEventHandler).apply(this, arguments));
      }

      _createClass(SelectCollectionManagementToolbarDefaultEventHandler, [{
        key: "addAssetListEntry",
        value: function addAssetListEntry(itemData) {
          (0, _frontendJsWeb.openSimpleInputModal)({
            dialogTitle: itemData.title,
            formSubmitURL: itemData.addAssetListEntryURL,
            mainFieldLabel: Liferay.Language.get('title'),
            mainFieldName: 'title',
            mainFieldPlaceholder: Liferay.Language.get('title'),
            namespace: itemData.namespace,
            spritemap: this.spritemap
          });
        }
      }]);

      return SelectCollectionManagementToolbarDefaultEventHandler;
    }(_frontendJsWeb.DefaultEventHandler);

    SelectCollectionManagementToolbarDefaultEventHandler.STATE = {
      spritemap: _metalState.Config.string()
    };
    var _default = SelectCollectionManagementToolbarDefaultEventHandler;
    exports["default"] = _default;
    //# sourceMappingURL=SelectCollectionManagementToolbarDefaultEventHandler.es.js.map
  }
});
//# sourceMappingURL=SelectCollectionManagementToolbarDefaultEventHandler.es.js.map

==> com.liferay.layout.admin.web-4.0.79.jar: META-INF/resources/js/SelectCollectionManagementToolbarDefaultEventHandler.es.js <==
Liferay.Loader.define("layout-admin-web@4.0.79/js/SelectCollectionManagementToolbarDefaultEventHandler.es", ['module', 'exports', 'require', 'frontend-js-web', 'frontend-js-metal-web$metal-state'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;

    var _frontendJsWeb = require("frontend-js-web");

    var _metalState = require("frontend-js-metal-web$metal-state");

    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }

    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
    }

    function _possibleConstructorReturn(self, call) {
      if (call && (_typeof(call) === "object" || typeof call === "function")) {
        return call;
      }return _assertThisInitialized(self);
    }

    function _assertThisInitialized(self) {
      if (self === void 0) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
      }return self;
    }

    function _getPrototypeOf(o) {
      _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
        return o.__proto__ || Object.getPrototypeOf(o);
      };return _getPrototypeOf(o);
    }

    function _inherits(subClass, superClass) {
      if (typeof superClass !== "function" && superClass !== null) {
        throw new TypeError("Super expression must either be null or a function");
      }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
    }

    function _setPrototypeOf(o, p) {
      _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
        o.__proto__ = p;return o;
      };return _setPrototypeOf(o, p);
    }

    var SelectCollectionManagementToolbarDefaultEventHandler = /*#__PURE__*/function (_DefaultEventHandler) {
      _inherits(SelectCollectionManagementToolbarDefaultEventHandler, _DefaultEventHandler);

      function SelectCollectionManagementToolbarDefaultEventHandler() {
        _classCallCheck(this, SelectCollectionManagementToolbarDefaultEventHandler);

        return _possibleConstructorReturn(this, _getPrototypeOf(SelectCollectionManagementToolbarDefaultEventHandler).apply(this, arguments));
      }

      _createClass(SelectCollectionManagementToolbarDefaultEventHandler, [{
        key: "addAssetListEntry",
        value: function addAssetListEntry(itemData) {
          (0, _frontendJsWeb.openSimpleInputModal)({
            dialogTitle: itemData.title,
            formSubmitURL: itemData.addAssetListEntryURL,
            mainFieldLabel: Liferay.Language.get('title'),
            mainFieldName: 'title',
            mainFieldPlaceholder: Liferay.Language.get('title'),
            namespace: itemData.namespace,
            spritemap: this.spritemap
          });
        }
      }]);

      return SelectCollectionManagementToolbarDefaultEventHandler;
    }(_frontendJsWeb.DefaultEventHandler);

    SelectCollectionManagementToolbarDefaultEventHandler.STATE = {
      spritemap: _metalState.Config.string()
    };
    var _default = SelectCollectionManagementToolbarDefaultEventHandler;
    exports.default = _default;
    //# sourceMappingURL=SelectCollectionManagementToolbarDefaultEventHandler.es.js.map
  }
});
//# sourceMappingURL=SelectCollectionManagementToolbarDefaultEventHandler.es.js.map
